/* migstat07_sas.zip:   02 Vorlauf 2007.sas */

OPTIONS NOFMTERR; RUN;   /* ohne Formate */

/* Arbeitsverzeichnis in '<...>' eintragen; z. B. c:\temp */
libname mzjahr '<Arbeitsverzeichnis'>;

/* ====================================================================

SAS-PROGRAMME ZUR TYPISIERUNG DES MIGRATIONSSTATUS IM MIKROZENSUS 2007 

Programmautor/en:
SAS-Originalprogramm: Gunter Brueckner (Statistisches Bundesamt;
             Referat F 204 Migration und integration, Wohnen);
Anpassungen an Scientific Use File Mikrozensus 2007: Delia Jaeger, 
             Bernhard Schimpl-Neimanns (GESIS, GML)

Programmzweck:
   Diese Programmreihe dient der Replikation des Migrationsstatus, Variable 
   MIG, und der Staatsangehoerigkeit zum Migrationsstatus (MIGS) im 
   Scientific Use File (SUF) des Mikrozensus 2007.
   Die Programme basieren auf den SAS-Programmen zum Original-Mikrozensus 
   des Statistischen Bundesamtes und wurden an Recodierungen des SUF 
   angepasst.
   Bei der Replikation der Variablen Staatsangehoerigkeit zum Migrationsstatus
   (MIGS) ist zu beachten, dass aus Gruenden des Datenschutzes Angaben zur 
   zweiten Staatsangehoerigkeit (EF370) nur rudimentaer vorhanden sind. 
   Des Weiteren sind die zur Konstruktion von MIGS verwendeten Variablen
       EF369 1. Staatsangehoerigkeit
   und EF374 Staatsangehoerigkeit: vor Einbuergerung/Zuzug als Spaetaussiedler
   unterschiedlich codiert. Die Replikation ist deshalb nur eingeschraenkt 
   moeglich.

Weiterfuehrende Programmbeschreibung:                                
   Jaeger, Delia und Bernhard Schimpl-Neimanns: Typisierung des       
   Migrationshintergrundes in den Mikrozensus Scientific-Use-Files    
   2005-2009. GESIS-Technical Report Nr. 2012/08. Mannheim: GESIS.    
   URL: http://www.gesis.org/fileadmin/upload/forschung/publikationen/
        gesis_reihen/gesis_methodenberichte/2012/TechnicalReport_2012-08.pdf

Download dieser Datei:                                               
   http://www.gesis.org/missy/studie/klassifikationen/konzepte-und-definitionen/
   migrationshintergrund/migstat07_sas.zip                                              

Siehe auch Anhang 1: Personen mit Migrationshintergrund - Auf        
   dem Weg zu einer definitorischen Abgrenzung - S. 398-407 in:       
   Statistisches Bundesamt, 2011: Bevoelkerung mit Migrationshintergrund.
   Ergebnisse des Mikrozensus 2009. Fachserie 1 Reihe 2.2. Wiesbaden. 
   URL: https://www.destatis.de/DE/Publikationen/Thematisch/Bevoelkerung/
   MigrationIntegration/Migrationshintergrund2010220097004.pdf?__blob= 
   publicationFile; letzter Zugriff: 24.07.2012            
                                                                    
Programmstruktur:
0. Datenvorbereitung: ID_2007.sas, 02 Vorlauf 2007.sas, 03 Grundtypisierung MigH 2007.sas
1. Grundtypisierung des Migationshintergrundes: 03 Grundtypisierung MigH 2007.sas
2. Identifikation von 3-Generationen-Haushalten: 04 Grosseltern-Eltern 2007.sas
3. Endtypisierung der Grosseltern: 05 Endtypisierung Grosseltern 2007.sas
4. Endtypisierung der Eltern: 06 Endtypisierung Eltern 2007.sas
5. Endtypisierung Befragte: 07 Endtypisierung Befragte 2007.sas
6. Umsetzung von Zeitreihenkompatibilitaet (nur MZ 2005 und 2009, entfaellt im MZ 2008)
7. Variablendefinition fuer SUF- und Fachserien-Ergebnisse: 07 Endtypisierung Befragte 2007.sas

Programmstatus:
  Getestet mit SAS 9.1 for Windows und dem Scientific Use File Mikrozensus 2007,
  Version 1 vom 04. 12. 2009. 
  Stand: Juli 2012.
*/


/* ====================================================================
0. Datenvorbereitung

   Programm zur Rekodierung doppelter Identifikatoren im Scientific Use File 
   des Mikrozensus 2007: Nr. des Haushalts im Auswahlbezirk (EF4) und Nummer 
   der Person im Haushalt (EF5).
   [...]
   - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   Quelle http://www.gesis.org/missy/home/auswahl-datensatz/mikrozensus-2007/
       --- Arbeitshilfen: Rekodierung doppelter Identifikatoren --- 
   URL: http://www.gesis.org/missy/fileadmin/missy/daten/mikrodaten_tools/
        Rekodierung_doppelter_Identifikatoren/ID_2007.sas
 
--- geringfuegig modifiziert fuer die Typisierung des Migrationsstatus ---
--------------------------------------------------------------------------- 
Ausgangsdaten: Scientific Use File Mikrozensus 2007: mz2007
   Variablenauswahl: Zur Abgrenzung eines Haushalts und Variablen fuer 
      Erstellung des Migrationsstatus erforderliche Variablen 
Ergebnis: Datei mit revidierter Haushalts- (EF4) und Personennummer (EF5): mz2007r 

Falls bereits korrigierte Daten vorliegen, kann das Kommando deaktiviert werden. */
* Vollstaendigen Dateinamen inkl. Verzeichnis in <> eintragen;
%include "<ID_2007.sas>";

/* 2007 keine Jahresueberhaenge (keine Variable EF5b)
   Mit Verwendung der korrigierten HH-Nr. EF4R (=>EF4) kann bei der Abgrenzung 
   von Haushalten auf Variable EF12 Berichtsquartal verzichtet werden.
 */


/* Vorlauf 
   Die Vorlaufprozedur selektiert die validen Spaetaussiedler, d.h.
   Zugewanderte mit EF372=2 in der Bevoelkerung am Haupt- und Nebenwohnsitz.
   Gespeichert wird nur EF1-EF5 und Zuzugsjahr; die Daten dienen dem
   Ermitteln von Ehegatten/Kindern von Spaetaussiedlern, die den Status von 
   Eingebuergerten haben */

data mzjahr.vorlauf (KEEP=_EF1_ _EF3_ _EF4_ _EF5_ _Jahrzuzug_);
	set  mzjahr.mz2007r;

	if ef367 = 1949 then JahrZuzug=1949;   /* Zuzug vor 1950 */
	else if ef367 = 9999 then JahrZuzug=9; /* o.A. zum Zuzugsjahr */
	else if ef367 = 0 then JahrZuzug=0;    /* kein Zuzugsjahr sinnvoll */
	else JahrZuzug=ef367;                  /* Zuzug 1950-200X */

	_EF1_ = EF1; _EF3_ = EF3; _EF4_ = EF4; _EF5_= EF5; _jahrzuzug_=jahrzuzug;
	
	if EF366 = 8 and EF372 = 2 and Jahrzuzug>1949 then do;
		output mzjahr.vorlauf;
	end;
run;
